Coverage report

File | function | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
lmcat\__init__.py | (no function) | 2 | 0 | 0 | 100%
lmcat\__main__.py | (no function) | 3 | 3 | 0 | 0%
lmcat\lmcat.py | LMCatConfig.load | 11 | 5 | 0 | 55%
lmcat\lmcat.py | LMCatConfig.read | 17 | 17 | 0 | 0%
lmcat\lmcat.py | IgnoreHandler.__init__ | 4 | 0 | 0 | 100%
lmcat\lmcat.py | IgnoreHandler._init_parser | 7 | 0 | 0 | 100%
lmcat\lmcat.py | IgnoreHandler.is_ignored | 3 | 0 | 0 | 100%
lmcat\lmcat.py | sorted_entries | 3 | 0 | 0 | 100%
lmcat\lmcat.py | walk_dir | 17 | 0 | 0 | 100%
lmcat\lmcat.py | walk_and_collect | 8 | 1 | 0 | 88%
lmcat\lmcat.py | main | 36 | 36 | 0 | 0%
lmcat\lmcat.py | (no function) | 39 | 6 | 0 | 85%
tests\test_lmcat.py | ensure_clean_dir | 3 | 1 | 0 | 67%
tests\test_lmcat.py | test_lmcat_config_defaults | 5 | 0 | 0 | 100%
tests\test_lmcat.py | test_lmcat_config_load_partial | 6 | 0 | 0 | 100%
tests\test_lmcat.py | test_lmcat_config_load_all | 6 | 0 | 0 | 100%
tests\test_lmcat.py | test_ignore_handler_init | 6 | 0 | 0 | 100%
tests\test_lmcat.py | test_ignore_handler_basic_ignore | 9 | 0 | 0 | 100%
tests\test_lmcat.py | test_ignore_handler_directory_patterns | 13 | 0 | 0 | 100%
tests\test_lmcat.py | test_ignore_handler_negation | 10 | 0 | 0 | 100%
tests\test_lmcat.py | test_ignore_handler_nested_ignore_files | 11 | 0 | 0 | 100%
tests\test_lmcat.py | test_ignore_handler_gitignore_disabled | 7 | 0 | 0 | 100%
tests\test_lmcat.py | test_walk_dir_basic | 19 | 0 | 0 | 100%
tests\test_lmcat.py | test_walk_dir_with_ignore | 18 | 0 | 0 | 100%
tests\test_lmcat.py | test_walk_and_collect_complex | 21 | 0 | 0 | 100%
tests\test_lmcat.py | test_cli_output_file | 19 | 5 | 0 | 74%
tests\test_lmcat.py | test_cli_tree_only | 17 | 5 | 0 | 71%
tests\test_lmcat.py | (no function) | 22 | 0 | 0 | 100%
Total |  | 342 | 79 | 0 | 77%

No items found using the specified filter.